@@ -121,8 +121,10 @@ fn fetch_spot_markets() -> Result<Vec<Market>> {
                 symbol: m.symbol,
                 base_id,
                 quote_id,
+                settle_id: None,
                 base,
                 quote,
+                settle: None,
                 active: true,
                 margin: false,
                 // see https://www.bitglobal.com/en-us/fee
